@@ -126,16 +126,6 @@ class ActionCable::Channel::BaseTest < ActionCable::TestCase
     assert_not_predicate @channel, :subscribed?
   end
 
-  test "unsubscribed? method returns correct status" do
-    assert_not @channel.unsubscribed?
-
-    @channel.subscribe_to_channel
-    assert_not @channel.unsubscribed?
-
-    @channel.unsubscribe_from_channel
-    assert_predicate @channel, :unsubscribed?
-  end
-
   test "connection identifiers" do
     assert_equal @user.name, @channel.current_user.name
   end
@@ -252,6 +242,7 @@ class ActionCable::Channel::BaseTest < ActionCable::TestCase
       assert_equal 1, events.length
       assert_equal "transmit_subscription_confirmation.action_cable", events[0].name
       assert_equal "ActionCable::Channel::BaseTest::ChatChannel", events[0].payload[:channel_class]
+      assert_equal "{id: 1}", events[0].payload[:identifier]
     end
   ensure
     ActiveSupport::Notifications.unsubscribe "transmit_subscription_confirmation.action_cable"
@@ -266,6 +257,7 @@ class ActionCable::Channel::BaseTest < ActionCable::TestCase
     assert_equal 1, events.length
     assert_equal "transmit_subscription_rejection.action_cable", events[0].name
     assert_equal "ActionCable::Channel::BaseTest::ChatChannel", events[0].payload[:channel_class]
+    assert_equal "{id: 1}", events[0].payload[:identifier]
   ensure
     ActiveSupport::Notifications.unsubscribe "transmit_subscription_rejection.action_cable"
   end
