@@ -2,6 +2,7 @@
 
 require "cases/helper"
 require "models/user"
+require "models/pilot"
 require "models/visitor"
 
 class SecurePasswordTest < ActiveModel::TestCase
@@ -12,6 +13,7 @@ class SecurePasswordTest < ActiveModel::TestCase
 
     @user = User.new
     @visitor = Visitor.new
+    @pilot = Pilot.new
 
     # Simulate loading an existing user from the DB
     @existing_user = User.new
@@ -102,14 +104,6 @@ class SecurePasswordTest < ActiveModel::TestCase
     assert_equal ["doesn't match Password"], @user.errors[:password_confirmation]
   end
 
-  test "create a new user with validation, a spaces only password, and an incorrect password confirmation" do
-    @user.password = " "
-    @user.password_confirmation = "something else"
-    assert_not @user.valid?(:create), "user should be invalid"
-    assert_equal 1, @user.errors.count
-    assert_equal ["doesn't match Password"], @user.errors[:password_confirmation]
-  end
-
   test "resetting password to nil clears the password cache" do
     @user.password = "password"
     @user.password = nil
@@ -185,14 +179,6 @@ class SecurePasswordTest < ActiveModel::TestCase
     assert_equal ["doesn't match Password"], @existing_user.errors[:password_confirmation]
   end
 
-  test "updating an existing user with validation, a spaces only password, and an incorrect password confirmation" do
-    @existing_user.password = " "
-    @existing_user.password_confirmation = "something else"
-    assert_not @existing_user.valid?(:update), "user should be invalid"
-    assert_equal 1, @existing_user.errors.count
-    assert_equal ["doesn't match Password"], @existing_user.errors[:password_confirmation]
-  end
-
   test "updating an existing user with validation and a correct password challenge" do
     @existing_user.password = "new password"
     @existing_user.password_challenge = "password"
@@ -330,4 +316,12 @@ class SecurePasswordTest < ActiveModel::TestCase
     @user.password = "secret"
     assert_equal BCrypt::Engine::MIN_COST, @user.password_digest.cost
   end
+
+  test "password reset token" do
+    assert_not @person.respond_to? :password_reset_token
+    assert_equal "password_reset-token-900", @pilot.password_reset_token
+
+    assert_equal "finding-for-password_reset-by-999", Pilot.find_by_password_reset_token("999")
+    assert_equal "finding-for-password_reset-by-999!", Pilot.find_by_password_reset_token!("999")
+  end
 end
