@@ -1,7 +1,6 @@
 # frozen_string_literal: true
 
 require "cases/helper"
-require "models/attachment"
 require "models/developer"
 require "models/project"
 require "models/company"
@@ -32,9 +31,6 @@ require "models/tree"
 require "models/node"
 require "models/club"
 require "models/cpk"
-require "models/sharded/blog"
-require "models/sharded/blog_post"
-require "models/sharded/comment"
 
 class BelongsToAssociationsTest < ActiveRecord::TestCase
   fixtures :accounts, :companies, :developers, :projects, :topics,
@@ -404,32 +400,6 @@ class BelongsToAssociationsTest < ActiveRecord::TestCase
     assert_equal 3, book.shop_id
   end
 
-  def test_clearing_optional_cpk_belongs_to_should_preserve_shared_pk
-    book = Cpk::Book.create!(id: [1, 2], title: "The Well-Grounded Rubyist")
-    chapter = Cpk::OptionalChapter.create!(id: [1, 2], book: book)
-
-    assert_equal book, chapter.book
-    assert_equal [1, 2], chapter.id
-
-    chapter.update!(book: nil)
-
-    assert_equal [1, 2], chapter.id
-    assert_nil chapter.book_id
-    assert_equal chapter.author_id, book.author_id
-  end
-
-  def test_should_reload_association_on_model_with_query_constraints_when_foreign_key_changes
-    blog = Sharded::Blog.create!
-    blog_post = Sharded::BlogPost.create!(blog: blog)
-    comment = Sharded::Comment.create!(blog: blog)
-
-    # Load the association once
-    comment.blog_post
-    comment.blog_post_id = blog_post.id
-
-    assert_equal blog_post, comment.blog_post
-  end
-
   def test_building_the_belonging_object_with_implicit_sti_base_class
     account = Account.new
     company = account.build_firm
@@ -1464,20 +1434,6 @@ class BelongsToAssociationsTest < ActiveRecord::TestCase
     assert_equal touch_time, car.reload.wheels_owned_at
   end
 
-  def test_polymorphic_stale_state_handles_nil_foreign_keys_correctly
-    klass = Class.new(ActiveRecord::Base) do
-      self.table_name = "records"
-
-      has_one :attachment, as: :record
-
-      def self.polymorphic_name
-        "Blob"
-      end
-    end
-
-    assert_nothing_raised { Attachment.create!(record: klass.build, record_type: "Document") }
-  end
-
   def test_build_with_conditions
     client = companies(:second_client)
     firm   = client.build_bob_firm
@@ -1883,3 +1839,37 @@ class BelongsToWithForeignKeyTest < ActiveRecord::TestCase
     assert_not Author.exists?(author.id)
   end
 end
+
+class AsyncBelongsToAssociationsTest < ActiveRecord::TestCase
+  include WaitForAsyncTestHelper
+
+  self.use_transactional_tests = false
+
+  fixtures :companies
+
+  unless in_memory_db?
+    def test_async_load_belongs_to
+      client = Client.find(3)
+      first_firm = companies(:first_firm)
+
+      client.association(:firm).async_load_target
+      wait_for_async_query
+
+      events = []
+      callback = -> (event) do
+        events << event unless event.payload[:name] == "SCHEMA"
+      end
+      ActiveSupport::Notifications.subscribed(callback, "sql.active_record") do
+        client.firm
+      end
+
+      assert_no_queries do
+        assert_equal first_firm, client.firm
+        assert_equal first_firm.name, client.firm.name
+      end
+
+      assert_equal 1, events.size
+      assert_equal true, events.first.payload[:async]
+    end
+  end
+end
