@@ -15,12 +15,23 @@ require "models/contact"
 require "models/keyboard"
 require "models/numeric_data"
 require "models/cpk"
-require "models/book_identifier"
 
 class AttributeMethodsTest < ActiveRecord::TestCase
   include InTimeZone
 
-  fixtures :topics, :developers, :companies, :computers, :book_identifiers
+  class EpochTimestamp < ActiveRecord::Type::DateTime
+    def deserialize(time_or_int)
+      Time.at(time_or_int).utc if time_or_int
+    end
+
+    def serialize(time)
+      time.to_i if time
+    end
+  end
+
+  ActiveRecord::Type.register(:epoch_timestamp, EpochTimestamp)
+
+  fixtures :topics, :developers, :companies, :computers
 
   def setup
     @old_matchers = ActiveRecord::Base.send(:attribute_method_patterns).dup
@@ -43,17 +54,6 @@ class AttributeMethodsTest < ActiveRecord::TestCase
     assert_includes new_topic_model.attribute_aliases, "id_value"
   end
 
-  test "#id_value alias is not defined if id_value column exist" do
-    new_book_identifier_model = Class.new(ActiveRecord::Base) do
-      self.table_name = "book_identifiers"
-    end
-
-    new_book_identifier_model.define_attribute_methods
-    assert_includes new_book_identifier_model.attribute_names, "id"
-    assert_includes new_book_identifier_model.attribute_names, "id_value"
-    assert_empty new_book_identifier_model.attribute_aliases
-  end
-
   test "aliasing `id` attribute allows reading the column value" do
     topic = Topic.create(id: 123_456, title: "title").becomes(TitlePrimaryKeyTopic)
 
@@ -75,14 +75,6 @@ class AttributeMethodsTest < ActiveRecord::TestCase
     assert_equal 1, topic.id_value
   end
 
-  test "#id_value returns the value in the id_value column, when id_value column exists" do
-    book_identifier = BookIdentifier.new
-    assert_nil book_identifier.id_value
-
-    book_identifier = BookIdentifier.find(1)
-    assert_equal book_identifiers(:awdr_isbn13).id_value, book_identifier.id_value
-  end
-
   test "#id_value alias is not defined if id column doesn't exist" do
     keyboard = Keyboard.create!
 
@@ -931,9 +923,67 @@ class AttributeMethodsTest < ActiveRecord::TestCase
   end
 
   test "time zone-aware attributes do not recurse infinitely on invalid values" do
+    model = new_topic_like_ar_class { }
+
+    type = model.type_for_attribute(:bonus_time)
+    assert_kind_of ActiveRecord::Type::Time, type
+
+    invalid_time = []
+    record = model.new(bonus_time: invalid_time)
+    assert_equal invalid_time, record.bonus_time
+
+    invalid_time = Time.current.utc.to_i
+    record = model.new(bonus_time: invalid_time)
+    assert_equal invalid_time, record.bonus_time
+
     in_time_zone "Pacific Time (US & Canada)" do
-      record = @target.new(bonus_time: [])
-      assert_nil record.bonus_time
+      model = new_topic_like_ar_class { }
+
+      type = model.type_for_attribute(:bonus_time)
+      assert_kind_of ActiveRecord::AttributeMethods::TimeZoneConversion::TimeZoneConverter, type
+
+      invalid_time = []
+      record = model.new(bonus_time: invalid_time)
+      assert_equal invalid_time, record.bonus_time
+
+      invalid_time = Time.current.utc.to_i
+      record = model.new(bonus_time: invalid_time)
+      assert_equal invalid_time, record.bonus_time
+    end
+  end
+
+  test "time zone-aware custom attributes" do
+    timestamp = Time.current.utc.to_i
+
+    model = Class.new(ActiveRecord::Base)
+    model.table_name = "minimalistics"
+
+    model.attribute :expires_at, :epoch_timestamp
+
+    type = model.type_for_attribute(:expires_at)
+    assert_kind_of EpochTimestamp, type
+
+    record_1 = model.create!(expires_at: timestamp)
+    assert_equal timestamp, record_1.expires_at.to_i
+
+    model.insert!({ expires_at: timestamp })
+    record_2 = model.last
+    assert_not_equal record_1, record_2
+    assert_equal timestamp, record_2.expires_at.to_i
+
+    in_time_zone "Pacific Time (US & Canada)" do
+      model.attribute :expires_at, :epoch_timestamp
+
+      type = model.type_for_attribute(:expires_at)
+      assert_kind_of ActiveRecord::AttributeMethods::TimeZoneConversion::TimeZoneConverter, type
+
+      record_1 = model.create!(expires_at: timestamp)
+      assert_equal timestamp, record_1.expires_at.to_i
+
+      model.insert!({ expires_at: timestamp })
+      record_2 = model.last
+      assert_not_equal record_1, record_2
+      assert_equal timestamp, record_2.expires_at.to_i
     end
   end
 
@@ -1501,7 +1551,6 @@ class AttributeMethodsTest < ActiveRecord::TestCase
     assert_equal "Text", comment.text
   end
 
-
   test "#alias_attribute with a manually defined method raises an error" do
     class_with_aliased_manually_defined_method = Class.new(ActiveRecord::Base) do
       def self.name
