@@ -5,10 +5,12 @@ require "cases/helper"
 module ActiveRecord
   module ConnectionAdapters
     class SchemaCacheTest < ActiveRecord::TestCase
+      self.use_transactional_tests = false
+
       def setup
-        @connection       = ARUnit2Model.connection
-        @cache            = new_bound_reflection
-        @database_version = @connection.get_database_version
+        @pool = ARUnit2Model.connection_pool
+        @connection = ARUnit2Model.lease_connection
+        @cache = new_bound_reflection
         @check_schema_cache_dump_version_was = SchemaReflection.check_schema_cache_dump_version
       end
 
@@ -16,12 +18,12 @@ module ActiveRecord
         SchemaReflection.check_schema_cache_dump_version = @check_schema_cache_dump_version_was
       end
 
-      def new_bound_reflection(connection = @connection)
-        BoundSchemaReflection.new(SchemaReflection.new(nil), connection)
+      def new_bound_reflection(pool = @pool)
+        BoundSchemaReflection.new(SchemaReflection.new(nil), pool)
       end
 
-      def load_bound_reflection(filename, connection = @connection)
-        BoundSchemaReflection.new(SchemaReflection.new(filename), connection).tap do |cache|
+      def load_bound_reflection(filename, pool = @pool)
+        BoundSchemaReflection.new(SchemaReflection.new(filename), pool).tap do |cache|
           cache.load!
         end
       end
@@ -46,7 +48,7 @@ module ActiveRecord
         SchemaReflection.check_schema_cache_dump_version = false
         assert reflection.cached?("courses")
 
-        cache = BoundSchemaReflection.new(reflection, :__unused_connection__)
+        cache = BoundSchemaReflection.new(reflection, :__unused_pool__)
         assert cache.cached?("courses")
       end
 
@@ -67,7 +69,6 @@ module ActiveRecord
           assert cache.data_source_exists?("courses")
           assert_equal "id", cache.primary_keys("courses")
           assert_equal 1, cache.indexes("courses").size
-          assert_equal @database_version.to_s, cache.database_version.to_s
         end
       ensure
         tempfile.unlink
@@ -104,7 +105,6 @@ module ActiveRecord
           assert cache.data_source_exists?(@connection, "courses")
           assert_equal "id", cache.primary_keys(@connection, "courses")
           assert_equal 1, cache.indexes(@connection, "courses").size
-          assert_equal @database_version.to_s, cache.database_version(@connection).to_s
         end
 
         # Load the cache the usual way.
@@ -116,7 +116,6 @@ module ActiveRecord
           assert cache.data_source_exists?("courses")
           assert_equal "id", cache.primary_keys("courses")
           assert_equal 1, cache.indexes("courses").size
-          assert_equal @database_version.to_s, cache.database_version.to_s
         end
       ensure
         tempfile.unlink
@@ -136,23 +135,11 @@ module ActiveRecord
       def test_yaml_loads_5_1_dump_without_indexes_still_queries_for_indexes
         cache = load_bound_reflection(schema_dump_path)
 
-        assert_queries :any, ignore_none: true do
+        assert_queries_count(include_schema: true) do
           assert_equal 1, cache.indexes("courses").size
         end
       end
 
-      def test_yaml_loads_5_1_dump_without_database_version_still_queries_for_database_version
-        cache = load_bound_reflection(schema_dump_path)
-
-        # We can't verify queries get executed because the database version gets
-        # cached in both MySQL and PostgreSQL outside of the schema cache.
-
-        assert_not_nil reflection = @cache.instance_variable_get(:@schema_reflection)
-        assert_nil reflection.instance_variable_get(:@cache)
-
-        assert_equal @database_version.to_s, cache.database_version.to_s
-      end
-
       def test_primary_key_for_existent_table
         assert_equal "id", @cache.primary_keys("courses")
       end
@@ -189,18 +176,6 @@ module ActiveRecord
         assert_equal [], @cache.indexes("omgponies")
       end
 
-      def test_caches_database_version
-        @cache.database_version # cache database_version
-
-        assert_no_queries do
-          assert_equal @database_version.to_s, @cache.database_version.to_s
-
-          if current_adapter?(:Mysql2Adapter, :TrilogyAdapter)
-            assert_not_nil @cache.database_version.full_version_string
-          end
-        end
-      end
-
       def test_clearing
         @cache.columns("courses")
         @cache.columns_hash("courses")
@@ -211,9 +186,6 @@ module ActiveRecord
         @cache.clear!
 
         assert_equal 0, @cache.size
-        reflection = @cache.instance_variable_get(:@schema_reflection)
-        schema_cache = reflection.instance_variable_get(:@cache)
-        assert_nil schema_cache.instance_variable_get(:@database_version)
       end
 
       def test_marshal_dump_and_load
@@ -223,10 +195,6 @@ module ActiveRecord
         # Populate it.
         cache.add("courses")
 
-        # We're going to manually dump, so we also need to force
-        # database_version to be stored.
-        cache.database_version
-
         # Create a new cache by marshal dumping / loading.
         cache = Marshal.load(Marshal.dump(cache.instance_variable_get(:@schema_reflection).instance_variable_get(:@cache)))
 
@@ -236,7 +204,6 @@ module ActiveRecord
           assert cache.data_source_exists?(@connection, "courses")
           assert_equal "id", cache.primary_keys(@connection, "courses")
           assert_equal 1, cache.indexes(@connection, "courses").size
-          assert_equal @database_version.to_s, cache.database_version(@connection).to_s
         end
       end
 
@@ -257,7 +224,6 @@ module ActiveRecord
           assert cache.data_source_exists?("courses")
           assert_equal "id", cache.primary_keys("courses")
           assert_equal 1, cache.indexes("courses").size
-          assert_equal @database_version.to_s, cache.database_version.to_s
         end
       ensure
         tempfile.unlink
@@ -265,7 +231,9 @@ module ActiveRecord
 
       def test_marshal_dump_and_load_with_ignored_tables
         old_ignore = ActiveRecord.schema_cache_ignored_tables
+        assert_not ActiveRecord.schema_cache_ignored_table?("professors")
         ActiveRecord.schema_cache_ignored_tables = ["professors"]
+        assert ActiveRecord.schema_cache_ignored_table?("professors")
         # Create an empty cache.
         cache = new_bound_reflection
 
@@ -316,7 +284,6 @@ module ActiveRecord
           assert cache.data_source_exists?(@connection, "courses")
           assert_equal "id", cache.primary_keys(@connection, "courses")
           assert_equal 1, cache.indexes(@connection, "courses").size
-          assert_equal @database_version.to_s, cache.database_version(@connection).to_s
         end
 
         # Load a new cache.
@@ -328,7 +295,6 @@ module ActiveRecord
           assert cache.data_source_exists?("courses")
           assert_equal "id", cache.primary_keys("courses")
           assert_equal 1, cache.indexes("courses").size
-          assert_equal @database_version.to_s, cache.database_version.to_s
         end
       ensure
         tempfile.unlink
@@ -361,7 +327,13 @@ module ActiveRecord
       end
 
       def test_clear_data_source_cache
+        # Cache data sources list.
+        assert @cache.data_source_exists?("courses")
+
         @cache.clear_data_source_cache!("courses")
+        assert_queries_count(1, include_schema: true) do
+          @cache.data_source_exists?("courses")
+        end
       end
 
       test "#columns_hash? is populated by #columns_hash" do
@@ -389,28 +361,29 @@ module ActiveRecord
           ActiveRecord::Base.establish_connection(new_config)
 
           # cache starts empty
-          assert_equal 0, ActiveRecord::Base.connection.pool.schema_reflection.instance_variable_get(:@cache).size
+          assert_nil ActiveRecord::Base.connection_pool.schema_reflection.instance_variable_get(:@cache)
 
           # now we access the cache, causing it to load
-          assert ActiveRecord::Base.connection.schema_cache.version
+          assert_not_nil ActiveRecord::Base.schema_cache.version
 
           assert File.exist?(tempfile)
-          assert ActiveRecord::Base.connection.pool.schema_reflection.instance_variable_get(:@cache)
+          assert_not_nil ActiveRecord::Base.connection_pool.schema_reflection.instance_variable_get(:@cache)
 
           # assert cache is still empty on new connection (precondition for the
           # following to show it is loading because of the config change)
           ActiveRecord::Base.establish_connection(new_config)
 
           assert File.exist?(tempfile)
-          assert_equal 0, ActiveRecord::Base.connection.pool.schema_reflection.instance_variable_get(:@cache).size
+          assert_nil ActiveRecord::Base.connection_pool.schema_reflection.instance_variable_get(:@cache)
 
           # cache is loaded upon connection when lazily loading is on
           old_config = ActiveRecord.lazily_load_schema_cache
           ActiveRecord.lazily_load_schema_cache = true
           ActiveRecord::Base.establish_connection(new_config)
+          ActiveRecord::Base.connection_pool.lease_connection.verify!
 
           assert File.exist?(tempfile)
-          assert ActiveRecord::Base.connection.pool.schema_reflection.instance_variable_get(:@cache)
+          assert_not_nil ActiveRecord::Base.connection_pool.schema_reflection.instance_variable_get(:@cache)
         ensure
           ActiveRecord.lazily_load_schema_cache = old_config
           ActiveRecord::Base.establish_connection(:arunit)
@@ -449,7 +422,6 @@ module ActiveRecord
         assert_equal expected, coder["data_sources"]
         assert_equal expected, coder["indexes"]
         assert coder.key?("version")
-        assert coder.key?("database_version")
       end
 
       private
