@@ -469,7 +469,7 @@ class EnumTest < ActiveRecord::TestCase
     e = assert_raises(ArgumentError) do
       Class.new(ActiveRecord::Base) do
         self.table_name = "books"
-        enum status: [proposed: 1, written: 2, published: 3]
+        enum :status, [proposed: 1, written: 2, published: 3]
       end
     end
 
@@ -478,7 +478,7 @@ class EnumTest < ActiveRecord::TestCase
     e = assert_raises(ArgumentError) do
       Class.new(ActiveRecord::Base) do
         self.table_name = "books"
-        enum status: { "" => 1, "active" => 2 }
+        enum :status, { "" => 1, "active" => 2 }
       end
     end
 
@@ -487,7 +487,7 @@ class EnumTest < ActiveRecord::TestCase
     e = assert_raises(ArgumentError) do
       Class.new(ActiveRecord::Base) do
         self.table_name = "books"
-        enum status: ["active", ""]
+        enum :status, ["active", ""]
       end
     end
 
@@ -496,7 +496,7 @@ class EnumTest < ActiveRecord::TestCase
     e = assert_raises(ArgumentError) do
       Class.new(ActiveRecord::Base) do
         self.table_name = "books"
-        enum status: Object.new
+        enum :status, Object.new
       end
     end
 
@@ -506,7 +506,7 @@ class EnumTest < ActiveRecord::TestCase
   test "reserved enum names" do
     klass = Class.new(ActiveRecord::Base) do
       self.table_name = "books"
-      enum status: [:proposed, :written, :published]
+      enum :status, [:proposed, :written, :published]
     end
 
     conflicts = [
@@ -517,7 +517,7 @@ class EnumTest < ActiveRecord::TestCase
 
     conflicts.each_with_index do |name, i|
       e = assert_raises(ArgumentError) do
-        klass.class_eval { enum name => ["value_#{i}"] }
+        klass.class_eval { enum name, ["value_#{i}"] }
       end
       assert_match(/You tried to define an enum named "#{name}" on the model/, e.message)
     end
@@ -526,7 +526,7 @@ class EnumTest < ActiveRecord::TestCase
   test "reserved enum values" do
     klass = Class.new(ActiveRecord::Base) do
       self.table_name = "books"
-      enum status: [:proposed, :written, :published]
+      enum :status, [:proposed, :written, :published]
     end
 
     conflicts = [
@@ -535,13 +535,13 @@ class EnumTest < ActiveRecord::TestCase
       :save,     # generates #save!, which conflicts with an AR method
       :proposed, # same value as an existing enum
       :public, :private, :protected, # some important methods on Module and Class
-      :name, :parent, :superclass,
+      :name, :superclass,
       :id        # conflicts with AR querying
     ]
 
     conflicts.each_with_index do |value, i|
       e = assert_raises(ArgumentError, "enum value `#{value}` should not be allowed") do
-        klass.class_eval { enum "status_#{i}" => [value] }
+        klass.class_eval { enum "status_#{i}", [value] }
       end
       assert_match(/You tried to define an enum named .* on the model/, e.message)
     end
@@ -551,8 +551,8 @@ class EnumTest < ActiveRecord::TestCase
     assert_nothing_raised do
       Class.new(ActiveRecord::Base) do
         self.table_name = "books"
-        enum status_1: [:id], _prefix: true
-        enum status_2: [:id], _suffix: true
+        enum :status_1, [:id], prefix: true
+        enum :status_2, [:id], suffix: true
       end
     end
   end
@@ -568,7 +568,7 @@ class EnumTest < ActiveRecord::TestCase
       e = assert_raises(ArgumentError, "enum value `#{value}` should not be allowed") do
         Class.new(ActiveRecord::Base) do
           self.table_name = "books"
-          enum category: [:other, value]
+          enum :category, [:other, value]
         end
       end
       assert_match(/You tried to define an enum named .* on the model/, e.message)
@@ -585,7 +585,7 @@ class EnumTest < ActiveRecord::TestCase
           "do publish work..."
         end
 
-        enum status: [:proposed, :written, :published]
+        enum :status, [:proposed, :written, :published]
 
         def written!
           super
@@ -598,7 +598,7 @@ class EnumTest < ActiveRecord::TestCase
   test "validate uniqueness" do
     klass = Class.new(ActiveRecord::Base) do
       def self.name; "Book"; end
-      enum status: [:proposed, :written]
+      enum :status, [:proposed, :written]
       validates_uniqueness_of :status
     end
     klass.delete_all
@@ -612,7 +612,7 @@ class EnumTest < ActiveRecord::TestCase
   test "validate inclusion of value in array" do
     klass = Class.new(ActiveRecord::Base) do
       def self.name; "Book"; end
-      enum status: [:proposed, :written]
+      enum :status, [:proposed, :written]
       validates_inclusion_of :status, in: ["written"]
     end
     invalid_book = klass.new(status: "proposed")
@@ -624,12 +624,12 @@ class EnumTest < ActiveRecord::TestCase
   test "enums are distinct per class" do
     klass1 = Class.new(ActiveRecord::Base) do
       self.table_name = "books"
-      enum status: [:proposed, :written]
+      enum :status, [:proposed, :written]
     end
 
     klass2 = Class.new(ActiveRecord::Base) do
       self.table_name = "books"
-      enum status: [:drafted, :uploaded]
+      enum :status, [:drafted, :uploaded]
     end
 
     book1 = klass1.proposed.create!
@@ -645,7 +645,7 @@ class EnumTest < ActiveRecord::TestCase
     subklass1 = Class.new(Book)
 
     subklass2 = Class.new(Book) do
-      enum status: [:drafted, :uploaded]
+      enum :status, [:drafted, :uploaded]
     end
 
     book1 = subklass1.proposed.create!
@@ -671,29 +671,13 @@ class EnumTest < ActiveRecord::TestCase
     assert_match(/can't modify frozen/, e.message)
   end
 
-  test "declare multiple enums at a time" do
-    klass = Class.new(ActiveRecord::Base) do
-      self.table_name = "books"
-      enum status: [:proposed, :written, :published],
-           nullable_status: [:single, :married]
-    end
-
-    book1 = klass.proposed.create!
-    assert_predicate book1, :proposed?
-
-    book2 = klass.single.create!
-    assert_predicate book2, :single?
-  end
-
-  test "declare multiple enums with { _prefix: true }" do
+  test "declare multiple enums with prefix: true" do
     klass = Class.new(ActiveRecord::Base) do
       self.table_name = "books"
 
-      enum(
-        status: [:value_1],
-        last_read: [:value_1],
-        _prefix: true
-      )
+      enum(:status, [:value_1], prefix: true)
+
+      enum(:last_read, [:value_1], prefix: true)
     end
 
     instance = klass.new
@@ -701,15 +685,13 @@ class EnumTest < ActiveRecord::TestCase
     assert_respond_to instance, :last_read_value_1?
   end
 
-  test "declare multiple enums with { _suffix: true }" do
+  test "declare multiple enums with suffix: true" do
     klass = Class.new(ActiveRecord::Base) do
       self.table_name = "books"
 
-      enum(
-        status: [:value_1],
-        last_read: [:value_1],
-        _suffix: true
-      )
+      enum(:status, [:value_1], suffix: true)
+
+      enum(:last_read, [:value_1], suffix: true)
     end
 
     instance = klass.new
@@ -721,7 +703,7 @@ class EnumTest < ActiveRecord::TestCase
     klass = Class.new(ActiveRecord::Base) do
       self.table_name = "books"
       alias_attribute :aliased_status, :status
-      enum aliased_status: [:proposed, :written, :published]
+      enum :aliased_status, [:proposed, :written, :published]
     end
 
     book = klass.proposed.create!
@@ -785,8 +767,8 @@ class EnumTest < ActiveRecord::TestCase
 
   test "uses default status when no status is provided in fixtures" do
     book = books(:tlg)
-    assert book.proposed?, "expected fixture to default to proposed status"
-    assert book.in_english?, "expected fixture to default to english language"
+    assert_predicate book, :proposed?, "expected fixture to default to proposed status"
+    assert_predicate book, :in_english?, "expected fixture to default to english language"
   end
 
   test "uses default value from database on initialization" do
@@ -807,30 +789,12 @@ class EnumTest < ActiveRecord::TestCase
     klass = Class.new(ActiveRecord::Base) do
       self.table_name = "books"
       attribute :status, default: 2
-      enum status: [:proposed, :written, :published]
+      enum :status, [:proposed, :written, :published]
     end
 
     assert_equal "published", klass.new.status
   end
 
-  test "overloaded default by :_default" do
-    klass = Class.new(ActiveRecord::Base) do
-      self.table_name = "books"
-      enum status: [:proposed, :written, :published], _default: :published
-    end
-
-    assert_equal "published", klass.new.status
-  end
-
-  test "scopes can be disabled by :_scopes" do
-    klass = Class.new(ActiveRecord::Base) do
-      self.table_name = "books"
-      enum status: [:proposed, :written], _scopes: false
-    end
-
-    assert_raises(NoMethodError) { klass.proposed }
-  end
-
   test "overloaded default by :default" do
     klass = Class.new(ActiveRecord::Base) do
       self.table_name = "books"
@@ -840,6 +804,61 @@ class EnumTest < ActiveRecord::TestCase
     assert_equal "published", klass.new.status
   end
 
+  test ":_default is invalid in the new API" do
+    error = assert_raises(ArgumentError) do
+      Class.new(ActiveRecord::Base) do
+        self.table_name = "books"
+        enum :status, [:proposed, :written, :published], _default: :published
+      end
+    end
+
+    assert_match(/invalid option\(s\): :_default/, error.message)
+  end
+
+  test ":_prefix is invalid in the new API" do
+    error = assert_raises(ArgumentError) do
+      Class.new(ActiveRecord::Base) do
+        self.table_name = "books"
+        enum :status, [:proposed, :written, :published], _prefix: true
+      end
+    end
+
+    assert_match(/invalid option\(s\): :_prefix/, error.message)
+  end
+
+  test ":_suffix is invalid in the new API" do
+    error = assert_raises(ArgumentError) do
+      Class.new(ActiveRecord::Base) do
+        self.table_name = "books"
+        enum :status, [:proposed, :written, :published], _suffix: true
+      end
+    end
+
+    assert_match(/invalid option\(s\): :_suffix/, error.message)
+  end
+
+  test ":_scopes is invalid in the new API" do
+    error = assert_raises(ArgumentError) do
+      Class.new(ActiveRecord::Base) do
+        self.table_name = "books"
+        enum :status, [:proposed, :written, :published], _scopes: false
+      end
+    end
+
+    assert_match(/invalid option\(s\): :_scopes/, error.message)
+  end
+
+  test ":_instance_methods is invalid in the new API" do
+    error = assert_raises(ArgumentError) do
+      Class.new(ActiveRecord::Base) do
+        self.table_name = "books"
+        enum :status, [:proposed, :written, :published], _instance_methods: false
+      end
+    end
+
+    assert_match(/invalid option\(s\): :_instance_methods/, error.message)
+  end
+
   test "scopes can be disabled by :scopes" do
     klass = Class.new(ActiveRecord::Base) do
       self.table_name = "books"
@@ -873,6 +892,17 @@ class EnumTest < ActiveRecord::TestCase
     assert_respond_to book, :easy_to_read?
   end
 
+  test "enum labels as keyword arguments" do
+    klass = Class.new(ActiveRecord::Base) do
+      self.table_name = "books"
+      enum :status, active: 0, archived: 1
+    end
+
+    book = klass.new
+    assert_predicate book, :active?
+    assert_not_predicate book, :archived?
+  end
+
   test "option names can be used as label" do
     klass = Class.new(ActiveRecord::Base) do
       self.table_name = "books"
@@ -889,7 +919,7 @@ class EnumTest < ActiveRecord::TestCase
   test "scopes are named like methods" do
     klass = Class.new(ActiveRecord::Base) do
       self.table_name = "cats"
-      enum breed: { "American Bobtail" => 0, "Balinese-Javanese" => 1 }
+      enum :breed, { "American Bobtail" => 0, "Balinese-Javanese" => 1 }
     end
 
     assert_respond_to klass, :American_Bobtail
@@ -899,7 +929,7 @@ class EnumTest < ActiveRecord::TestCase
   test "capital characters for enum names" do
     klass = Class.new(ActiveRecord::Base) do
       self.table_name = "computers"
-      enum extendedWarranty: [:extendedSilver, :extendedGold]
+      enum :extendedWarranty, [:extendedSilver, :extendedGold]
     end
 
     computer = klass.extendedSilver.build
@@ -910,7 +940,7 @@ class EnumTest < ActiveRecord::TestCase
   test "unicode characters for enum names" do
     klass = Class.new(ActiveRecord::Base) do
       self.table_name = "books"
-      enum language: [:🇺🇸, :🇪🇸, :🇫🇷]
+      enum :language, [:🇺🇸, :🇪🇸, :🇫🇷]
     end
 
     book = klass.🇺🇸.build
@@ -921,7 +951,7 @@ class EnumTest < ActiveRecord::TestCase
   test "mangling collision for enum names" do
     klass = Class.new(ActiveRecord::Base) do
       self.table_name = "computers"
-      enum timezone: [:"Etc/GMT+1", :"Etc/GMT-1"]
+      enum :timezone, [:"Etc/GMT+1", :"Etc/GMT-1"]
     end
 
     computer = klass.public_send(:"Etc/GMT+1").build
@@ -934,7 +964,7 @@ class EnumTest < ActiveRecord::TestCase
     written = Struct.new(:to_s).new("written")
     klass = Class.new(ActiveRecord::Base) do
       self.table_name = "books"
-      enum status: { proposed => 0, written => 1 }
+      enum :status, { proposed => 0, written => 1 }
     end
 
     book = klass.create!(status: 0)
@@ -982,7 +1012,7 @@ class EnumTest < ActiveRecord::TestCase
         "Book"
       end
       silence_warnings do
-        enum status: [:sent, :not_sent]
+        enum :status, [:sent, :not_sent]
       end
     end
 
@@ -1006,7 +1036,7 @@ class EnumTest < ActiveRecord::TestCase
         "Book"
       end
       silence_warnings do
-        enum status: [:not_sent, :sent]
+        enum :status, [:not_sent, :sent]
       end
     end
 
@@ -1025,9 +1055,7 @@ class EnumTest < ActiveRecord::TestCase
       def self.name
         "Book"
       end
-      silence_warnings do
-        enum status: [:not_sent]
-      end
+      enum :status, [:not_sent]
     end
 
     assert_empty(logger.logged(:warn))
@@ -1046,7 +1074,7 @@ class EnumTest < ActiveRecord::TestCase
         "Book"
       end
       silence_warnings do
-        enum status: [:not_sent, :sent], _scopes: false
+        enum :status, [:not_sent, :sent], scopes: false
       end
     end
 
@@ -1057,11 +1085,9 @@ class EnumTest < ActiveRecord::TestCase
 
   test "raises for attributes with undeclared type" do
     klass = Class.new(Book) do
-      def self.name
-        "Book"
-      end
-      enum typeless_genre: [:adventure, :comic]
-    end
+    def self.name; "Book"; end
+    enum :typeless_genre, [:adventure, :comic]
+  end
 
     error = assert_raises(RuntimeError) do
       klass.type_for_attribute(:typeless_genre)
@@ -1072,16 +1098,16 @@ class EnumTest < ActiveRecord::TestCase
   test "supports attributes declared with a explicit type" do
     klass = Class.new(Book) do
       attribute :my_genre, :integer
-      enum my_genre: [:adventure, :comic]
+      enum :my_genre, [:adventure, :comic]
     end
 
     assert_equal :integer, klass.type_for_attribute(:my_genre).type
   end
 
-  test "default methods can be disabled by :_instance_methods" do
+  test "default methods can be disabled by :instance_methods" do
     klass = Class.new(ActiveRecord::Base) do
       self.table_name = "books"
-      enum status: [:proposed, :written], _instance_methods: false
+      enum :status, [:proposed, :written], instance_methods: false
     end
 
     instance = klass.new
