@@ -47,6 +47,17 @@ class InsertAllTest < ActiveRecord::TestCase
     end
   end
 
+  def test_insert_with_type_casting_and_serialize_is_consistent
+    skip unless supports_insert_returning?
+
+    book_name = ["Array"]
+    created_book_id = Book.create!(name: book_name).id
+    inserted_book_id = Book.insert!({ name: book_name }, returning: :id).first["id"]
+    created_book = Book.find_by!(id: created_book_id)
+    inserted_book = Book.find_by!(id: inserted_book_id)
+    assert_equal created_book.name, inserted_book.name
+  end
+
   def test_insert_all
     assert_difference "Book.count", +10 do
       Book.insert_all! [
@@ -487,7 +498,7 @@ class InsertAllTest < ActiveRecord::TestCase
   end
 
   def test_upsert_all_respects_updated_at_precision_when_touched_implicitly
-    skip unless supports_insert_on_duplicate_update? && supports_datetime_with_precision?
+    skip unless supports_insert_on_duplicate_update?
 
     Book.insert_all [{ id: 101, name: "Out of the Silent Planet", published_on: Date.new(1938, 4, 1), updated_at: 5.years.ago, updated_on: 5.years.ago }]
 
@@ -577,7 +588,7 @@ class InsertAllTest < ActiveRecord::TestCase
   end
 
   def test_upsert_all_respects_created_at_precision_when_touched_implicitly
-    skip unless supports_insert_on_duplicate_update? && supports_datetime_with_precision?
+    skip unless supports_insert_on_duplicate_update?
 
     # A single upsert can occur exactly at the seconds boundary (when usec is naturally zero), so try multiple times.
     has_subsecond_precision = (1..100).any? do |i|
@@ -759,6 +770,8 @@ class InsertAllTest < ActiveRecord::TestCase
   end
 
   def test_upsert_all_has_many_through
+    skip unless supports_insert_on_duplicate_update?
+
     book = Book.first
     assert_raise(ArgumentError) { book.subscribers.upsert_all([ { nick: "Jimmy" } ]) }
   end
