@@ -13,7 +13,7 @@ module ActiveRecord
 
     def test_construction
       relation = Relation.new(FakeKlass, table: :b)
-      assert_equal FakeKlass, relation.klass
+      assert_equal FakeKlass, relation.model
       assert_equal :b, relation.table
       assert_not relation.loaded, "relation is not loaded"
     end
@@ -291,8 +291,7 @@ module ActiveRecord
 
     def test_select_quotes_when_using_from_clause
       skip_if_sqlite3_version_includes_quoting_bug
-      quoted_join = ActiveRecord::Base.lease_connection.quote_table_name("join")
-      selected = Post.select(:join).from(Post.select("id as #{quoted_join}")).map(&:join)
+      selected = Post.select(:join).from(Post.select("id as #{quote_table_name("join")}")).map(&:join)
       assert_equal Post.pluck(:id).sort, selected.sort
     end
 
@@ -356,22 +355,6 @@ module ActiveRecord
       end
     end
 
-    def test_relation_with_annotation_includes_comment_in_update_all_query
-      post_with_annotation = Post.annotate("foo")
-      all_count = Post.all.to_a.count
-      assert_queries_match(%r{/\* foo \*/}) do
-        assert_equal all_count, post_with_annotation.update_all(title: "Same title")
-      end
-    end
-
-    def test_relation_with_annotation_includes_comment_in_delete_all_query
-      post_with_annotation = Post.annotate("foo")
-      all_count = Post.all.to_a.count
-      assert_queries_match(%r{/\* foo \*/}) do
-        assert_equal all_count, post_with_annotation.delete_all
-      end
-    end
-
     def test_relation_without_annotation_does_not_include_an_empty_comment
       log = capture_sql do
         Post.where(id: 1).first
@@ -389,7 +372,7 @@ module ActiveRecord
     end
 
     def test_does_not_duplicate_optimizer_hints_on_merge
-      escaped_table = Post.lease_connection.quote_table_name("posts")
+      escaped_table = quote_table_name("posts")
       expected = "SELECT /*+ OMGHINT */ #{escaped_table}.* FROM #{escaped_table}"
       query = Post.optimizer_hints("OMGHINT").merge(Post.optimizer_hints("OMGHINT")).to_sql
       assert_equal expected, query
