@@ -59,6 +59,15 @@ class StrictLoadingTest < ActiveRecord::TestCase
     assert_raises ActiveRecord::StrictLoadingViolationError do
       developer.projects.last.firm
     end
+
+    assert_nothing_raised do
+      developer.projects_extended_by_name.to_a
+    end
+
+    assert developer.projects_extended_by_name.all?(&:strict_loading?)
+    assert_raises ActiveRecord::StrictLoadingViolationError do
+      developer.projects_extended_by_name.last.firm
+    end
   end
 
   def test_strict_loading_n_plus_one_only_mode_with_belongs_to
@@ -98,6 +107,20 @@ class StrictLoadingTest < ActiveRecord::TestCase
     end
   end
 
+  def test_default_mode_is_all
+    developer = Developer.first
+    assert_predicate developer, :strict_loading_all?
+  end
+
+  def test_default_mode_can_be_changed_globally
+    developer = Class.new(ActiveRecord::Base) do
+      self.strict_loading_mode = :n_plus_one_only
+      self.table_name = "developers"
+    end.new
+
+    assert_predicate developer, :strict_loading_n_plus_one_only?
+  end
+
   def test_strict_loading
     Developer.all.each { |d| assert_not d.strict_loading? }
     Developer.strict_loading.each { |d| assert_predicate d, :strict_loading? }
@@ -613,14 +636,6 @@ class StrictLoadingTest < ActiveRecord::TestCase
     end
   end
 
-  def test_does_not_raise_when_checking_if_new_record_included_in_eager_loaded_habtm_relation
-    Developer.first.projects << Project.first
-
-    developer = Developer.includes(:projects).strict_loading.first
-
-    assert_nothing_raised { developer.projects.include?(Project.new) }
-  end
-
   def test_strict_loading_violation_raises_by_default
     assert_equal :raise, ActiveRecord.action_on_strict_loading_violation
 
