@@ -7,10 +7,10 @@ module ActiveStorage
   end
 
   module VERSION
-    MAJOR = 7
-    MINOR = 2
-    TINY  = 3
-    PRE   = nil
+    MAJOR = 8
+    MINOR = 0
+    TINY  = 2
+    PRE   = "1"
 
     STRING = [MAJOR, MINOR, TINY, PRE].compact.join(".")
   end
