@@ -386,6 +386,11 @@ class EnumerableTests < ActiveSupport::TestCase
     assert_equal [[:opened, { price: 2, currency: :usd }], [:paid, { price: 1, currency: :eur }]], values.in_order_of(:first, [:opened, :paid])
   end
 
+  def test_in_order_of_with_filter_false
+    values = [ Payment.new(5), Payment.new(3), Payment.new(1) ]
+    assert_equal [ Payment.new(1), Payment.new(5), Payment.new(3) ], values.in_order_of(:price, [ 1, 5 ], filter: false)
+  end
+
   def test_sole
     expected_raise = Enumerable::SoleItemExpectedError
 
@@ -393,27 +398,6 @@ class EnumerableTests < ActiveSupport::TestCase
     assert_equal 1, GenericEnumerable.new([1]).sole
     assert_raise(expected_raise) { GenericEnumerable.new([1, 2]).sole }
     assert_raise(expected_raise) { GenericEnumerable.new([1, nil]).sole }
-    assert_raise(expected_raise) { GenericEnumerable.new(1..).sole }
-  end
-
-  def test_sole_returns_same_value_as_first_for_tuples
-    enum = Enumerator.new(1) { |yielder| yielder.yield(1, "one") }
-    assert_equal [1, "one"], enum.sole
-    assert_equal enum.first, enum.sole
-  end
-
-  class KeywordYielder
-    include Enumerable
-
-    def each
-      yield 1, two: 3
-    end
-  end
-
-  def test_sole_keyword_arguments
-    yielder = KeywordYielder.new
-    assert_equal [1, { two: 3 }], yielder.sole
-    assert_equal yielder.first, yielder.sole
   end
 
   def test_doesnt_bust_constant_cache
@@ -428,7 +412,5 @@ class EnumerableTests < ActiveSupport::TestCase
   private
     def constant_cache_invalidations
       RubyVM.stat(:constant_cache_invalidations)
-    rescue ArgumentError
-      RubyVM.stat(:global_constant_state) # RUBY_VERSION < "3.2"
     end
 end
