@@ -98,6 +98,17 @@ class HashWithIndifferentAccessTest < ActiveSupport::TestCase
     assert_raise(NoMethodError) { @integers.with_indifferent_access.dup.symbolize_keys! }
   end
 
+  def test_stringify_keys_stringifies_integer_keys_for_hash_with_indifferent_access
+    assert_equal({ "0" => 1, "1" => 2 }, @integers.with_indifferent_access.stringify_keys)
+    assert_equal({ "ints" => { "0" => 1, "1" => 2 } }, { ints: @integers }.with_indifferent_access.deep_stringify_keys)
+  end
+
+  def test_stringify_keys_stringifies_non_string_keys_for_hash_with_indifferent_access
+    object = Object.new
+    hash = { object => 1 }
+    assert_equal({ object.to_s => 1 }, hash.with_indifferent_access.stringify_keys)
+  end
+
   def test_deep_symbolize_keys_preserves_integer_keys_for_hash_with_indifferent_access
     assert_equal @nested_integers, @nested_integers.with_indifferent_access.deep_symbolize_keys
     assert_raise(NoMethodError) { @nested_integers.with_indifferent_access.deep_dup.deep_symbolize_keys! }
@@ -452,31 +463,9 @@ class HashWithIndifferentAccessTest < ActiveSupport::TestCase
     assert_equal(["A", "bbb"], hash.keys) # asserting that order of keys is unchanged
     assert_instance_of ActiveSupport::HashWithIndifferentAccess, hash
 
-    hash = ActiveSupport::HashWithIndifferentAccess.new(@integers).transform_keys { |k| k + 1 }
-
-    assert_equal([1, 2], hash.keys)
-
-    repeating_strings = { "a" => 1, "aa" => 2, "aaa" => 3 }
-
-    hash = ActiveSupport::HashWithIndifferentAccess.new(repeating_strings).transform_keys { |k| "#{k}a" }
-
-    assert_equal(%w[aa aaa aaaa], hash.keys)
-
     assert_raise TypeError do
       hash.transform_keys(nil)
     end
-
-    hash_with_default = Hash.new(:a)
-    hash = ActiveSupport::HashWithIndifferentAccess.new(hash_with_default).transform_keys(&:to_s)
-    assert_nil hash.default
-    hash = ActiveSupport::HashWithIndifferentAccess.new(hash_with_default).transform_keys { |k| k.to_s }
-    assert_nil hash.default
-
-    hash_with_default_proc = Hash.new { |h, k| h[k] = :b }
-    hash = ActiveSupport::HashWithIndifferentAccess.new(hash_with_default_proc).transform_keys(&:to_s)
-    assert_nil hash.default_proc
-    hash = ActiveSupport::HashWithIndifferentAccess.new(hash_with_default_proc).transform_keys { |k| k.to_s }
-    assert_nil hash.default_proc
   end
 
   def test_indifferent_deep_transform_keys
@@ -531,23 +520,6 @@ class HashWithIndifferentAccessTest < ActiveSupport::TestCase
     assert_raise TypeError do
       hash.transform_keys(nil)
     end
-
-    hash_with_default = Hash.new(:a)
-    hash = ActiveSupport::HashWithIndifferentAccess.new(hash_with_default).transform_keys!(&:to_s)
-    assert_equal :a, hash.default
-    assert_equal :a, hash_with_default.default
-
-    hash = ActiveSupport::HashWithIndifferentAccess.new(hash_with_default).transform_keys! { |k| k.to_s }
-    assert_equal :a, hash.default
-    assert_equal :a, hash_with_default.default
-
-    hash_with_default_proc = Hash.new { |h, k| h[k] = :b }
-    default_proc = hash_with_default_proc.default_proc
-
-    hash = ActiveSupport::HashWithIndifferentAccess.new(hash_with_default_proc).transform_keys!(&:to_s)
-    assert_equal default_proc, hash.default_proc
-    hash = ActiveSupport::HashWithIndifferentAccess.new(hash_with_default_proc).transform_keys! { |k| k.to_s }
-    assert_equal default_proc, hash.default_proc
   end
 
   def test_indifferent_deep_transform_keys_bang
