@@ -49,6 +49,7 @@ module GeneratorsTestHelper
     ActiveRecord::Base.configurations = {
       test: {
         "#{database_name}": {
+          adapter: "sqlite3",
           database: "db/#{database_name}.sqlite3",
           migrations_paths: "db/#{database_name}_migrate",
         },
@@ -61,9 +62,12 @@ module GeneratorsTestHelper
 
   def copy_routes
     routes = File.expand_path("../../lib/rails/generators/rails/app/templates/config/routes.rb.tt", __dir__)
+    routes = evaluate_template(routes, {
+      options: ActiveSupport::OrderedOptions.new
+    })
     destination = File.join(destination_root, "config")
     FileUtils.mkdir_p(destination)
-    FileUtils.cp routes, File.join(destination, "routes.rb")
+    File.write File.join(destination, "routes.rb"), routes
   end
 
   def copy_gemfile(*gemfile_entries)
@@ -74,6 +78,13 @@ module GeneratorsTestHelper
     File.write File.join(destination, "Gemfile"), gemfile
   end
 
+  def copy_application_system_test_case
+    content = File.read(File.expand_path("../fixtures/test/application_system_test_case.rb", __dir__))
+    destination = File.join(destination_root, "test")
+    mkdir_p(destination)
+    File.write File.join(destination, "application_system_test_case.rb"), content
+  end
+
   def copy_dockerfile
     dockerfile = File.expand_path("../fixtures/Dockerfile.test", __dir__)
     dockerfile = evaluate_template_docker(dockerfile)
@@ -81,6 +92,25 @@ module GeneratorsTestHelper
     File.write File.join(destination, "Dockerfile"), dockerfile
   end
 
+  def copy_devcontainer_files
+    destination = File.join(destination_root, ".devcontainer")
+    mkdir_p(destination)
+
+    devcontainer_json = File.read(File.expand_path("../fixtures/.devcontainer/devcontainer.json", __dir__))
+    File.write File.join(destination, "devcontainer.json"), devcontainer_json
+
+    compose_yaml = File.read(File.expand_path("../fixtures/.devcontainer/compose.yaml", __dir__))
+    File.write File.join(destination, "compose.yaml"), compose_yaml
+  end
+
+  def copy_minimal_devcontainer_compose_file
+    destination = File.join(destination_root, ".devcontainer")
+    mkdir_p(destination)
+
+    compose_yaml = File.read(File.expand_path("../fixtures/.devcontainer/compose-minimal.yaml", __dir__))
+    File.write File.join(destination, "compose.yaml"), compose_yaml
+  end
+
   def evaluate_template(file, locals = {})
     erb = ERB.new(File.read(file), trim_mode: "-", eoutvar: "@output_buffer")
     context = Class.new do
@@ -96,17 +126,36 @@ module GeneratorsTestHelper
     erb.result()
   end
 
+  def assert_compose_file
+    assert_file ".devcontainer/compose.yaml" do |content|
+      yield YAML.load(content)
+    end
+  end
+
+  def assert_devcontainer_json_file
+    assert_file ".devcontainer/devcontainer.json" do |content|
+      yield JSON.load(content)
+    end
+  end
+
+  def run_app_update(app_root = destination_root, flags: "--force")
+    Dir.chdir(app_root) do
+      gemfile_contents = File.read("Gemfile")
+      gemfile_contents.sub!(/^(gem "rails").*/, "\\1, path: #{File.expand_path("../../..", __dir__).inspect}")
+      File.write("Gemfile", gemfile_contents)
+
+      silence_stream($stdout) { system({ "BUNDLE_GEMFILE" => "Gemfile" }, "bin/rails app:update #{flags}", exception: true) }
+    end
+  end
+
   private
     def gemfile_locals
       {
-        gem_ruby_version: RUBY_VERSION,
         rails_prerelease: false,
         skip_active_storage: true,
         depend_on_bootsnap: false,
         depends_on_system_test: false,
         options: ActiveSupport::OrderedOptions.new,
-        skip_sprockets: false,
-        bundler_windows_platforms: "windows",
       }
     end
 end
